@@ -1,6 +1,6 @@
 """A clean customisable Sphinx documentation theme."""
 
-__version__ = "2023.05.20"
+__version__ = "2023.07.26"
 
 import hashlib
 import logging
@@ -156,6 +156,11 @@ def _asset_hash(path: str) -> str:
 
 
 def _add_asset_hashes(static: List[str], add_digest_to: List[str]) -> None:
+    if sphinx.version_info >= (7, 1):
+        # https://github.com/sphinx-doc/sphinx/pull/11415 added the relevant
+        # functionality to Sphinx, so we don't need to do anything.
+        return
+
     for asset in add_digest_to:
         index = static.index("_static/" + asset)
         static[index].filename = _asset_hash(asset)  # type: ignore
